Attribute class

Marks a field as a reactive attribute.

Changes to the attribute in the DOM will update this field, and changes to this field (via syncAttributes) will update the DOM.

Constructors

Attribute()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited