Blob class abstract

A file-like object of immutable, raw data.

See: https://developer.mozilla.org/en-US/docs/Web/API/Blob

Constructors

Blob()

Properties

hashCode → int
The hash code for this object.
no setterinherited
raw → dynamic
The underlying platform object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter
type → String
no setter

Methods

arrayBuffer() → Future<ByteBuffer>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slice([int? start, int? end, String? contentType]) → Blob
stream() → Stream<Uint8List>
text() → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited