CSSStyleDeclaration class abstract

Represents an element's inline CSS styles.

See: https://developer.mozilla.org/en-US/docs/Web/API/CSSStyleDeclaration

Constructors

CSSStyleDeclaration()

Properties

display ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
opacity ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibility ↔ String
getter/setter pair

Methods

getPropertyValue(String property) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeProperty(String property) → String
setProperty(String property, String value, [String? priority]) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited