CssBackgroundOrigin class sealed

CSS background-origin property values.

Implemented types

Constructors

CssBackgroundOrigin.global(CssGlobal global)
Global keyword (inherit, initial, unset, revert).
factory
CssBackgroundOrigin.multiple(List<CssBackgroundOrigin> values)
Multiple background-origin values for multiple background images.
factory
CssBackgroundOrigin.raw(String value)
Raw CSS value escape hatch.
factory
CssBackgroundOrigin.variable(String varName)
CSS variable reference.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() → String
Converts this value to its CSS string representation.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

borderBox → const CssBackgroundOrigin
The background extends to the outside edge of the border.
contentBox → const CssBackgroundOrigin
The background extends to the outside edge of the content.
paddingBox → const CssBackgroundOrigin
The background extends to the outside edge of the padding.