CssBorderStyle class sealed

CSS border-style values.

Implemented types

Constructors

CssBorderStyle.global(CssGlobal global)
Global keyword (inherit, initial, unset, revert).
factory
CssBorderStyle.raw(String value)
Raw CSS value escape hatch.
factory
CssBorderStyle.variable(String varName)
CSS variable reference.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() → String
Converts this value to its CSS string representation.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

dashed → const CssBorderStyle
dotted → const CssBorderStyle
double_ → const CssBorderStyle
groove → const CssBorderStyle
hidden → const CssBorderStyle
inset → const CssBorderStyle
none → const CssBorderStyle
outset → const CssBorderStyle
ridge → const CssBorderStyle
solid → const CssBorderStyle