CssDuration class sealed

CSS duration values.

Implemented types

Constructors

CssDuration.ms(num milliseconds)
Duration in milliseconds.
factory
CssDuration.raw(String value)
Raw CSS value escape hatch.
factory
CssDuration.s(num seconds)
Duration in seconds.
factory
CssDuration.variable(String varName)
CSS variable reference.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() String
Converts this value to its CSS string representation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited