CssFontWeight class sealed

CSS font-weight property values.

Implemented types

Constructors

CssFontWeight.global(CssGlobal global)
Global keyword (inherit, initial, unset, revert).
factory
CssFontWeight.numeric(int weight)
Numeric weight (1-1000, typically 100-900 in increments of 100).
factory
CssFontWeight.raw(String value)
Raw CSS value escape hatch.
factory
CssFontWeight.variable(String varName)
CSS variable reference.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() → String
Converts this value to its CSS string representation.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bold → const CssFontWeight
bolder → const CssFontWeight
lighter → const CssFontWeight
normal → const CssFontWeight
w100 → const CssFontWeight
w200 → const CssFontWeight
w300 → const CssFontWeight
w400 → const CssFontWeight
w500 → const CssFontWeight
w600 → const CssFontWeight
w700 → const CssFontWeight
w800 → const CssFontWeight
w900 → const CssFontWeight