CssGradientStop class

Represents a color stop in a gradient.

Constructors

CssGradientStop(CssColor color, [CssLength? offset])
Creates a new gradient color stop.
const

Properties

color → CssColor
The color at this stop.
final
hashCode → int
The hash code for this object.
no setterinherited
offset → CssLength?
The position of the stop along the gradient line.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() → String
Converts the stop to its CSS string representation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited