DOMTokenList class abstract

A set of space-separated tokens (e.g., CSS classes via Element.classList).

See: https://developer.mozilla.org/en-US/docs/Web/API/DOMTokenList

Constructors

DOMTokenList()

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(String token) → void
contains(String token) → bool
item(int index) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String token) → void
replace(String oldToken, String newToken) → void
toggle(String token, [bool? force]) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited