DataTransfer class abstract

Holds the data being dragged during a drag-and-drop operation.

See: https://developer.mozilla.org/en-US/docs/Web/API/DataTransfer

Constructors

DataTransfer()

Properties

dropEffect ↔ String
getter/setter pair
effectAllowed ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<String>
no setter

Methods

clearData([String? format]) → void
getData(String format) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setData(String format, String data) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited