DevicePermissionDescriptor class
Descriptor for querying device permissions (camera, microphone).
See: https://developer.mozilla.org/en-US/docs/Web/API/Permissions/query
- Inheritance
-
- Object
- PermissionDescriptor
- DevicePermissionDescriptor
Constructors
- DevicePermissionDescriptor({required PermissionName name, String? deviceId})
-
const
Properties
- deviceId → String?
-
The device ID to query permission for, or
nullfor any device.final - hashCode → int
-
The hash code for this object.
no setterinherited
- name → PermissionName
-
The name of the permission to query.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited