Event class abstract

Represents an event that takes place on an EventTarget.

See: https://developer.mozilla.org/en-US/docs/Web/API/Event

Constructors

Event()

Properties

bubbles → bool
Whether the event bubbles up through the DOM.
no setter
cancelable → bool
Whether the event can be cancelled.
no setter
currentTarget → EventTarget?
The target whose event listener is currently being invoked.
no setter
hashCode → int
The hash code for this object.
no setterinherited
raw → dynamic
The underlying platform object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → EventTarget?
The target to which the event was dispatched.
no setter
type → String
The type of the event (e.g., 'click', 'input').
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
Cancels the event's default action.
stopImmediatePropagation() → void
Stops propagation and prevents other listeners on the same target.
stopPropagation() → void
Stops further propagation of the event.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited