ExternalDocumentation class

Allows referencing an external resource for extended documentation.

Constructors

ExternalDocumentation({String? description, required String url})
const

Properties

description → String?
A short description of the target documentation.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
The URL for the target documentation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited