FileList class abstract

A list of File objects (e.g., from an <input type="file">).

See: https://developer.mozilla.org/en-US/docs/Web/API/FileList

Constructors

FileList()

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

item(int index) File?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited