GeolocationCoordinates class abstract

Represents the position and altitude of the device on Earth, as well as the accuracy with which these properties are calculated.

See: https://developer.mozilla.org/en-US/docs/Web/API/GeolocationCoordinates

Constructors

GeolocationCoordinates()

Properties

accuracy → double
The accuracy of the latitude and longitude properties, expressed in meters.
no setter
altitude → double?
The position's altitude in meters, relative to sea level.
no setter
altitudeAccuracy → double?
The accuracy of the altitude expressed in meters.
no setter
hashCode → int
The hash code for this object.
no setterinherited
heading → double?
The direction in which the device is traveling, in degrees (0-360).
no setter
latitude → double
The position's latitude in decimal degrees.
no setter
longitude → double
The position's longitude in decimal degrees.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double?
The magnitude of the horizontal component of the device's velocity in m/s.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited