GeolocationPosition class abstract

Represents the position of the concerned device at a given time.

See: https://developer.mozilla.org/en-US/docs/Web/API/GeolocationPosition

Constructors

GeolocationPosition()

Properties

coords → GeolocationCoordinates
The coordinates defining the current location.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
The time at which the location was retrieved (milliseconds since epoch).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited