GeolocationPositionError class abstract

Represents the reason of an error occurring when using the geolocating device.

See: https://developer.mozilla.org/en-US/docs/Web/API/GeolocationPositionError

Constructors

GeolocationPositionError()

Properties

code → int
The error code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String
A human-readable error message.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

PERMISSION_DENIED → const int
The acquisition of the geolocation information failed because the page didn't have the permission to do it.
POSITION_UNAVAILABLE → const int
The acquisition of the geolocation failed because at least one internal source of position returned an internal error.
TIMEOUT → const int
The time allowed to acquire the geolocation, defined by PositionOptions.timeout, was reached before the information was obtained.