list property
HTMLDataListElement?
get
list
Returns the datalist element that contains the options for this input.
Implementation
HTMLDataListElement? get list;
Returns the datalist element that contains the options for this input.
HTMLDataListElement? get list;