willValidate property
bool
get
willValidate
Whether the element is a candidate for constraint validation.
Implementation
bool get willValidate;
Whether the element is a candidate for constraint validation.
bool get willValidate;