ImageData class abstract

Represents pixel data for a rectangular area of a canvas.

See: https://developer.mozilla.org/en-US/docs/Web/API/ImageData

Constructors

ImageData()

Properties

data → List<int>
A one-dimensional array of RGBA pixel values (0–255).
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → int
Height of the image data in pixels.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Width of the image data in pixels.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited