Length class

Validates that a string length is within min and max.

Inheritance

Constructors

Length({int? min, int? max, String? message})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → int?
final
message → String?
final
min → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited