MutationObserverInit class

Initialization options for MutationObserver.observe.

Constructors

MutationObserverInit({bool? childList, bool? attributes, bool? characterData, bool? subtree, bool? attributeOldValue, bool? characterDataOldValue, List<String>? attributeFilter})
const

Properties

attributeFilter → List<String>?
final
attributeOldValue → bool?
final
attributes → bool?
final
characterData → bool?
final
characterDataOldValue → bool?
final
childList → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtree → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited