MutationRecord class abstract

Constructors

MutationRecord()

Properties

addedNodes → NodeList
no setter
attributeName → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
nextSibling → Node?
no setter
oldValue → String?
no setter
previousSibling → Node?
no setter
removedNodes → NodeList
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → Node
no setter
type → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited