Navigator class abstract

Information about the user agent.

See: https://developer.mozilla.org/en-US/docs/Web/API/Navigator

Constructors

Properties

clipboard → Clipboard
no setter
geolocation → Geolocation
no setter
hashCode → int
The hash code for this object.
no setterinherited
language → String
no setter
languages → List<String>
no setter
onLine → bool
no setter
permissions → Permissions
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgent → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited