NotificationOptions class

Constructors

NotificationOptions({String body = '', NotificationDirection dir = NotificationDirection.auto, String lang = '', String tag = '', String? icon, String? badge, String? image, Object? data, bool renotify = false, bool requireInteraction = false, bool? silent, int? timestamp, List<int>? vibrate, List<NotificationAction>? actions})
const

Properties

actions → List<NotificationAction>?
A list of actions to display in the notification.
final
badge → String?
The URL of the badge image.
final
body → String
The body text of the notification.
final
data → Object?
Arbitrary data associated with the notification.
final
dir → NotificationDirection
The direction in which to display the notification.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
The URL of the icon to be displayed.
final
image → String?
The URL of an image to be displayed in the notification.
final
lang → String
The notification's language, as a BCP 47 language tag.
final
renotify → bool
Whether the user should be re-notified when a notification with the same tag replaces an old one.
final
requireInteraction → bool
Whether the notification should remain active until the user clicks or dismisses it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
silent → bool?
Whether the notification should be silent.
final
tag → String
An identifying tag for the notification.
final
timestamp → int?
A timestamp (milliseconds since epoch) associated with the notification.
final
vibrate → List<int>?
A vibration pattern for the device's vibration hardware.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited