OpenApi class

global configuration for the OpenAPI specification.

Use this annotation to provide global metadata like title, version, and security requirements for the generated OpenAPI spec.

Constructors

OpenApi({String? title, String? version, String? description, List<String>? servers, List<Map<String, List<String>>>? security, Map<String, SecurityScheme>? securitySchemes})
Creates a new global OpenAPI configuration.
const

Properties

description → String?
A description of the API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
security → List<Map<String, List<String>>>?
Global security requirements for the API.
final
securitySchemes → Map<String, SecurityScheme>?
Global security schemes for the API.
final
servers → List<String>?
A list of servers providing the API.
final
title → String?
The title of the API.
final
version → String?
The version of the API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited