Parameter class

Describes a single operation parameter.

Constructors

Parameter({required String name, required String inLocation, String? description, bool? required, bool? deprecated, Map<String, dynamic>? schema, Type? type, bool? allowEmptyValue, String? style, bool? explode, bool? allowReserved, Object? example})
const

Properties

allowEmptyValue → bool?
Sets the ability to pass empty-valued parameters.
final
allowReserved → bool?
Determines whether the parameter value SHOULD allow reserved characters, as defined by RFC3986.
final
deprecated → bool?
Specifies that a parameter is deprecated and SHOULD be transitioned out of usage.
final
description → String?
A brief description of the parameter.
final
example → Object?
Example of the parameter's potential value.
final
explode → bool?
When this is true, parameter values of type array or object generate separate parameters for each value of the array or key-value pair of the map.
final
hashCode → int
The hash code for this object.
no setterinherited
inLocation → String
The location of the parameter.
final
name → String
The name of the parameter.
final
required → bool?
Determines whether this parameter is mandatory.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → Map<String, dynamic>?
The schema defining the type used for the parameter.
final
style → String?
Describes how the parameter value will be serialized depending on the type of the parameter value.
final
type → Type?
The Dart type used to generate the schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited