Pattern class

Validates that a string matches the given pattern.

Inheritance

Constructors

Pattern(String pattern, {String? message})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
pattern → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited