PermissionName class

The name of a permission that can be queried.

Use the predefined constants or construct with a raw string for forward-compatibility with future spec values.

See: https://developer.mozilla.org/en-US/docs/Web/API/Permissions/query#name

Constructors

PermissionName(String value)
Creates a permission name from a raw string value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override