prompt constant
PermissionState
const prompt
The user has not yet granted or denied the permission.
Implementation
static const prompt = PermissionState('prompt');
The user has not yet granted or denied the permission.
static const prompt = PermissionState('prompt');