PermissionStatus class abstract

Implemented types

Constructors

PermissionStatus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → PermissionName
The name of the permission.
no setter
onchange ↔ EventListener?
Called when the permission state changes.
getter/setter pair
raw → dynamic
The underlying platform object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → PermissionState
The current state of the permission.
no setter

Methods

addEventListener(String type, EventListener? callback) → void
Registers an event listener on this target.
inherited
dispatchEvent(Event event) → bool
Dispatches an event to this target.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener? callback) → void
Removes a previously registered event listener.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited