PointerEvent class abstract

Implemented types

Constructors

PointerEvent()

Properties

altKey → bool
no setterinherited
bubbles → bool
Whether the event bubbles up through the DOM.
no setterinherited
button → int
no setterinherited
buttons → int
no setterinherited
cancelable → bool
Whether the event can be cancelled.
no setterinherited
clientX → double
no setterinherited
clientY → double
no setterinherited
ctrlKey → bool
no setterinherited
currentTarget → EventTarget?
The target whose event listener is currently being invoked.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
no setter
isPrimary → bool
no setter
metaKey → bool
no setterinherited
pageX → double
no setterinherited
pageY → double
no setterinherited
pointerId → int
no setter
pointerType → String
no setter
pressure → double
no setter
raw → dynamic
The underlying platform object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenX → double
no setterinherited
screenY → double
no setterinherited
shiftKey → bool
no setterinherited
tangentialPressure → double
no setter
target → EventTarget?
The target to which the event was dispatched.
no setterinherited
tiltX → int
no setter
tiltY → int
no setter
twist → int
no setter
type → String
The type of the event (e.g., 'click', 'input').
no setterinherited
width → double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
Cancels the event's default action.
inherited
stopImmediatePropagation() → void
Stops propagation and prevents other listeners on the same target.
inherited
stopPropagation() → void
Stops further propagation of the event.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited