PositionOptions class

Constructors

PositionOptions({bool enableHighAccuracy = false, int? timeout, int maximumAge = 0})
const

Properties

enableHighAccuracy → bool
A boolean value that indicates the application would like to receive the best possible results.
final
hashCode → int
The hash code for this object.
no setterinherited
maximumAge → int
A positive long value indicating the maximum age in milliseconds of a possible cached position that is acceptable to return.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → int?
A positive long value representing the maximum length of time (in milliseconds) the device is allowed to take in order to return a position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited