PushPermissionDescriptor class

Descriptor for querying push notification permissions.

See: https://developer.mozilla.org/en-US/docs/Web/API/Permissions/query

Inheritance

Constructors

PushPermissionDescriptor({bool userVisibleOnly = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name PermissionName
The name of the permission to query.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userVisibleOnly bool
Whether the push subscription will only be used for messages whose effect is made visible to the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited