userVisibleOnly property

bool userVisibleOnly
final

Whether the push subscription will only be used for messages whose effect is made visible to the user.

Implementation

final bool userVisibleOnly;