RawHtml class

A raw HTML node. The content is rendered exactly as provided, without escaping. Use with caution.

Inheritance

Constructors

RawHtml(String html)

Properties

hashCode → int
The hash code for this object.
no setterinherited
html → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHtml() → String
Renders the node to an HTML string.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited