SecurityScheme class

Defines a security scheme for the API.

Constructors

SecurityScheme.apiKey({required String name, required String inLocation, String? description})
Creates an API Key security scheme.
const
SecurityScheme.http({required String scheme, String? bearerFormat, String? description})
Creates an HTTP security scheme (e.g., Basic, Bearer).
const
SecurityScheme.oauth2({required Map<String, SecuritySchemeFlow> flows, String? description})
Creates an OAuth2 security scheme.
const
SecurityScheme.openIdConnect({required String openIdConnectUrl, String? description})
Creates an OpenID Connect security scheme.
const

Properties

bearerFormat → String?
final
description → String?
final
flows → Map<String, SecuritySchemeFlow>?
final
hashCode → int
The hash code for this object.
no setterinherited
inLocation → String?
final
name → String?
final
openIdConnectUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited