SecuritySchemeFlow class

Defines an OAuth2 flow.

Constructors

SecuritySchemeFlow({String? authorizationUrl, String? tokenUrl, String? refreshUrl, Map<String, String>? scopes})
const

Properties

authorizationUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
refreshUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → Map<String, String>?
final
tokenUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited