ServerEvent class

Implemented types

Constructors

ServerEvent(String _type)

Properties

bubbles → bool
Whether the event bubbles up through the DOM.
no setteroverride
cancelable → bool
Whether the event can be cancelled.
no setteroverride
currentTarget → EventTarget?
The target whose event listener is currently being invoked.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
raw → dynamic
The underlying platform object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → EventTarget?
The target to which the event was dispatched.
no setteroverride
type → String
The type of the event (e.g., 'click', 'input').
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
Cancels the event's default action.
override
stopImmediatePropagation() → void
Stops propagation and prevents other listeners on the same target.
override
stopPropagation() → void
Stops further propagation of the event.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited