ServerTouchEvent class

Inheritance
Implemented types

Constructors

ServerTouchEvent([String type = 'touchstart'])

Properties

altKey → bool
no setteroverride
bubbles → bool
Whether the event bubbles up through the DOM.
no setterinherited
cancelable → bool
Whether the event can be cancelled.
no setterinherited
changedTouches → TouchList
no setteroverride
ctrlKey → bool
no setteroverride
currentTarget → EventTarget?
The target whose event listener is currently being invoked.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
metaKey → bool
no setteroverride
raw → dynamic
The underlying platform object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shiftKey → bool
no setteroverride
target → EventTarget?
The target to which the event was dispatched.
no setterinherited
targetTouches → TouchList
no setteroverride
touches → TouchList
no setteroverride
type → String
The type of the event (e.g., 'click', 'input').
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
Cancels the event's default action.
inherited
stopImmediatePropagation() → void
Stops propagation and prevents other listeners on the same target.
inherited
stopPropagation() → void
Stops further propagation of the event.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited