SparkHttpException class

Base HTTP Exception

Implemented types

Constructors

SparkHttpException(int statusCode, String message, {String code = 'HTTP_ERROR', Map<String, dynamic>? details})

Properties

code → String
final
details → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited