Touch class abstract

A single contact point on a touch-sensitive device.

See: https://developer.mozilla.org/en-US/docs/Web/API/Touch

Constructors

Touch()

Properties

clientX → double
no setter
clientY → double
no setter
force → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
identifier → int
no setter
pageX → double
no setter
pageY → double
no setter
radiusX → double
no setter
radiusY → double
no setter
rotationAngle → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenX → double
no setter
screenY → double
no setter
target → EventTarget
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited