ValidityState class abstract

The validity state of a form element.

See: https://developer.mozilla.org/en-US/docs/Web/API/ValidityState

Constructors

ValidityState()

Properties

badInput → bool
no setter
customError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
patternMismatch → bool
no setter
rangeOverflow → bool
no setter
rangeUnderflow → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepMismatch → bool
no setter
tooLong → bool
no setter
tooShort → bool
no setter
typeMismatch → bool
no setter
valid → bool
no setter
valueMissing → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited