Window class abstract

Implemented types

Constructors

Window()

Properties

console → Console
no setter
crypto → Crypto
no setter
customElements → CustomElementRegistry
no setter
document → Document
no setter
hashCode → int
The hash code for this object.
no setterinherited
history → History
no setter
localStorage → Storage
no setter
location → Location
no setter
no setter
performance → Performance
no setter
raw → dynamic
The underlying platform object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionStorage → Storage
no setter

Methods

addEventListener(String type, EventListener? callback) → void
Registers an event listener on this target.
inherited
alert([String? message]) → void
atob(String encodedData) → String
btoa(String data) → String
cancelAnimationFrame(int handle) → void
clearInterval(int handle) → void
clearTimeout(int handle) → void
confirm([String? message]) → bool
dispatchEvent(Event event) → bool
Dispatches an event to this target.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prompt([String? message, String? defaultValue]) → String?
removeEventListener(String type, EventListener? callback) → void
Removes a previously registered event listener.
inherited
requestAnimationFrame(void callback(num highResTime)) → int
setInterval(void callback(), [int delay = 0]) → int
setTimeout(void callback(), [int delay = 0]) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited