File class abstract
A file from the user's system.
- Implemented types
Constructors
- File()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModified → int
-
no setter
- name → String
-
no setter
- raw → dynamic
-
The underlying platform object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setterinherited
- type → String
-
no setterinherited
Methods
-
arrayBuffer(
) → Future< ByteBuffer> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
slice(
[int? start, int? end, String? contentType]) → Blob -
inherited
-
stream(
) → Stream< Uint8List> -
inherited
-
text(
) → Future< String> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited