POSITION_UNAVAILABLE constant
int
const POSITION_UNAVAILABLE
The acquisition of the geolocation failed because at least one internal source of position returned an internal error.
Implementation
static const int POSITION_UNAVAILABLE = 2;