PermissionName class
The name of a permission that can be queried.
Use the predefined constants or construct with a raw string for forward-compatibility with future spec values.
See: https://developer.mozilla.org/en-US/docs/Web/API/Permissions/query#name
Constructors
- PermissionName(String value)
-
Creates a permission name from a raw string value.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- backgroundFetch → const PermissionName
- backgroundSync → const PermissionName
- camera → const PermissionName
- clipboardRead → const PermissionName
- clipboardWrite → const PermissionName
- geolocation → const PermissionName
- microphone → const PermissionName
- notifications → const PermissionName
- persistentStorage → const PermissionName
- push → const PermissionName