Permissions class abstract
Provides methods for querying and requesting permissions.
See: https://developer.mozilla.org/en-US/docs/Web/API/Permissions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
PermissionDescriptor descriptor) → Future< PermissionStatus> - Queries the status of a given permission.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited