userVisibleOnly property
Whether the push subscription will only be used for messages whose effect is made visible to the user.
Implementation
final bool userVisibleOnly;
Whether the push subscription will only be used for messages whose effect is made visible to the user.
final bool userVisibleOnly;